@@ -290,7 +290,7 @@ static struct passwd *getuserenv(const char *uid, const char *cfgfile)
 	}
 
 	if(!pwd) {
-		fprintf(stderr, "*** sipw: unkown user identity; exiting\n");
+		fprintf(stderr, "*** sipw: unknown user identity; exiting\n");
 		exit(-1);
 	}
 
@@ -303,9 +303,15 @@ static struct passwd *getuserenv(const char *uid, const char *cfgfile)
 
 	if(uid) {
 		setenv("PWD", pwd->pw_dir, 1);
+		fsys::createDir(pwd->pw_dir, 0770);
 		if(!fsys::changeDir(pwd->pw_dir)) {
-			fsys::changeDir(buf);			
-			setenv("PWD", buf, 1);
+			fsys::createDir(DEFAULT_VARPATH "/lib/sipwitch", 0770);
+			if(fsys::changeDir(DEFAULT_VARPATH "/lib/sipwitch"))
+				setenv("PWD", DEFAULT_VARPATH "/lib/sipwitch", 1);
+			else {
+				fsys::changeDir(buf);			
+				setenv("PWD", buf, 1);
+			}
 		}
 	}
 	else {
@@ -689,6 +695,22 @@ extern "C" int main(int argc, char **argv)
 		if(!stricmp(*argv, "-help") || !stricmp(*argv, "-?")) 
 			server::usage();
 
+		if(!stricmp(*argv, "-debug")) {
+			++argv;
+			if(!*argv) {
+				fprintf(stderr, "*** sipw: debug level missing\n");
+				exit(-1);
+			}
+			verbose = atoi(*argv) + INFO;
+			continue;
+		}
+
+
+		if(!strnicmp(*argv, "-debug=", 7)) {
+			verbose = atoi(*argv + 7) + INFO;
+			continue;
+		} 
+
 		if(!strnicmp(*argv, "-x", 2)) {
 			if(*argv + 2)
 				cp = *argv + 2;
