@@ -593,6 +593,7 @@ registry::mapped *registry::allocate(const char *id)
 	service::keynode *node, *leaf;
 	unsigned ext = 0;
 	const char *cp = "none";
+	const char *cos = "none";
 	profile_t *pro = NULL;
 	bool listed = false;
 	service::usernode user;
@@ -635,7 +636,8 @@ registry::mapped *registry::allocate(const char *id)
 	if(node)
 		cp = node->getId();
 
-	if(!stricmp(cp, "user"))
+	cos = cp;
+	if(!stricmp(cp, "admin") || !stricmp(cp, "user"))
 		rr->type = MappedRegistry::USER;
 	else if(!stricmp(cp, "refer"))
 		rr->type = MappedRegistry::REFER;
@@ -643,7 +645,7 @@ registry::mapped *registry::allocate(const char *id)
 		rr->type = MappedRegistry::REJECT;
 	else if(!stricmp(cp, "gateway"))
 		rr->type = MappedRegistry::GATEWAY;
-	else if(!stricmp(cp, "service"))
+	else if(!stricmp(cp, "service") || !stricmp(cp, "device"))
 		rr->type = MappedRegistry::SERVICE;
 	if(!node || rr->type == MappedRegistry::EXPIRED) {
 		server::release(user);
@@ -730,11 +732,13 @@ registry::mapped *registry::allocate(const char *id)
 	if(leaf && leaf->getPointer())
 		ext = atoi(leaf->getPointer());
 
-	if(rr->type == MappedRegistry::USER) {
+	if(rr->isProfiled()) {
 		pro = NULL;
 		leaf = node->leaf("profile");
 		if(leaf)
 			pro = server::getProfile(leaf->getPointer());
+		if(!pro)
+			pro = server::getProfile(cos);
 		if(!pro)
 			pro = server::getProfile("*");
 		if(pro)
@@ -1232,7 +1236,7 @@ void registry::mapped::update(Socket::address& saddr, int changed)
 
 	time(&now);
 
-	if(changed == registry::target::UNKNOWN || !saddr.getAddr() || !expires || expires < now || type != MappedRegistry::USER)
+	if(changed == registry::target::UNKNOWN || !saddr.getAddr() || !expires || expires < now || !isUser())
 		return;
 
 	tp = internal.targets;
