@@ -294,6 +294,34 @@ void server::confirm(const char *user)
 	pp->value.level = 0;
 	pp->value.features = USER_PROFILE_RESTRICTED;
 
+	mp = (caddr_t)alloc(sizeof(profile));
+	pp = new(mp) profile(&profiles);
+	memcpy(&pp->value, &ppd->value, sizeof(profile_t));
+	String::set(pp->value.id, sizeof(pp->value.id), "local");
+	pp->value.level = 1;
+	pp->value.features = USER_PROFILE_LOCAL;
+
+	mp = (caddr_t)alloc(sizeof(profile));
+	pp = new(mp) profile(&profiles);
+	memcpy(&pp->value, &ppd->value, sizeof(profile_t));
+	String::set(pp->value.id, sizeof(pp->value.id), "device");
+	pp->value.level = 0;
+	pp->value.features = USER_PROFILE_DEVICE;
+
+	mp = (caddr_t)alloc(sizeof(profile));
+	pp = new(mp) profile(&profiles);
+	memcpy(&pp->value, &ppd->value, sizeof(profile_t));
+	String::set(pp->value.id, sizeof(pp->value.id), "service");
+	pp->value.level = 0;
+	pp->value.features = USER_PROFILE_SERVICE;
+
+	mp = (caddr_t)alloc(sizeof(profile));
+	pp = new(mp) profile(&profiles);
+	memcpy(&pp->value, &ppd->value, sizeof(profile_t));
+	String::set(pp->value.id, sizeof(pp->value.id), "admin");
+	pp->value.level = 9;
+	pp->value.features = USER_PROFILE_ADMIN;
+
 #ifdef	_MSWINDOWS_
 	char dbuf[256];
 	unsigned len;
