@@ -308,7 +308,7 @@ static void registry(char **argv)
 			type = "gw";
 			break;
 		case MappedRegistry::SERVICE:
-			type = "peer";
+			type = "svc";
 			break;
 		case MappedRegistry::TEMPORARY:
 			type = "temp";
